# Test input files
This directory contains a set of sample input files that are tested using the supplied model.

In the case of LinkML model, this set includes the model itself and, periodically, one may want to update the model
to include these files.

